__version__ = "0.0.1"
__author__ = "Jacob Jeffries"
__author_email__ = "jacob.jeffries@chicagoclubteam.org"
__url__ = "https://github.com/Chicago-Club-Management-Company/aqua-blue"

from .reservoir import EchoStateNetwork as EchoStateNetwork
from .time_series import TimeSeries as TimeSeries
